==> logNow-0.2.2.tar.gz: logNow-0.2.2/README.md <==
<p align="center">
<a href="https://github.com/NapoII">
    <img src="Readme_top.png"  alt=f"NapoII">
</a>
</p>

<center>

# logNow
</center>

<p align="center">
<a href="https://github.com/NapoII/logNow/archive/refs/heads/main.zip">
    <img src="https://img.shields.io/github/downloads/NapoII/logNow/total" alt="downloads/total">
</a>

<a href="https://github.com/NapoII/logNow/archive/refs/heads/main.zip">
    <img src="https://img.shields.io/github/repo-size/NapoII/logNow" alt="github/repo-size">
</a>

<a href="https://github.com/NapoII/logNow/blob/main/LICENSE">
    <img src="https://img.shields.io/github/license/NapoII/logNow" alt="github/license">
</a>

<a href="https://github.com/NapoII/logNow/actions">
    <img src="https://img.shields.io/github/last-commit/NapoII/logNow" alt="github/last-commit">
</a>

<a href="https://github.com/NapoII/logNow/issues">
    <img src="https://img.shields.io/github/issues/NapoII/logNow?style=plastic" alt="github/issues">
</a>

<a href="https://github.com/NapoII/logNow/stargazers">
    <img src="https://img.shields.io/github/stars/NapoII/logNow?style=social" alt="github/stars">
</a>

<a href="https://discord.gg/g7EW4P65">
    <img src="https://img.shields.io/discord/190307701169979393?style=plastic" alt="discord">
</a>
</p>

"logNow"(Nice Log) is a Python package created to simplify logging for developers working on Python applications. The package provides a simple logging function that allows developers to output log messages to a file with timestamps, instead of using the standard "print" statement.

With "logNow", developers can easily create custom log messages and output them to a log file, allowing them to monitor the behavior of their applications and quickly identify any errors or issues that arise. The package provides several useful features, including support for multiple log levels, the ability to configure log formatting, and the option to output logs to the console in addition to the log file.

In addition to its core functionality, "logNow" is designed to be easy to use and configure. The package is well-documented, and the code is written in a modular and extensible manner, making it easy for developers to customize and extend its functionality to suit their needs.

Overall, "logNow" is a valuable tool for any Python developer looking to simplify their logging process and effectively monitor their applications. Whether you're working on a small hobby project or a large-scale enterprise application, "logNow" can help you keep track of what's happening in your code and quickly identify and fix any issues that arise
## Running Locally

This application requires Python 3.10.7.
```
git clone https://github.com/NapoII/logNow
pip install -r requirements.txt
run Code logNow.py
```

## Example
coming soon...
## Lizenz

MIT License

Copyright (c) 2023 NapoII
<small><small><small>
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE
</small>

==> logNow-0.2.4.tar.gz: logNow-0.2.4/README.md <==
<p align="center">
<a href="https://github.com/NapoII">
    <img src="https://raw.githubusercontent.com/NapoII/logNow/main/Readme_top.png"  alt=f"NapoII">
</a>
</p>

<p align="center">
<a href="https://pypi.org/project/logNow/">
    <img src="https://img.shields.io/github/downloads/NapoII/logNow/total" alt="downloads/total">
</a>

<a href="https://pypi.org/project/logNow/">
    <img src="https://img.shields.io/github/repo-size/NapoII/logNow" alt="github/repo-size">
</a>

<a href="https://github.com/NapoII/logNow/blob/main/LICENSE">
    <img src="https://img.shields.io/github/license/NapoII/logNow" alt="github/license">
</a>

<a href="https://github.com/NapoII/logNow/actions">
    <img src="https://img.shields.io/github/last-commit/NapoII/logNow" alt="github/last-commit">
</a>

<a href="https://github.com/NapoII/logNow/issues">
    <img src="https://img.shields.io/github/issues/NapoII/logNow?style=plastic" alt="github/issues">
</a>

<a href="https://github.com/NapoII/logNow/stargazers">
    <img src="https://img.shields.io/github/stars/NapoII/logNow?style=social" alt="github/stars">
</a>

<a href="https://discord.gg/g7EW4P65">
    <img src="https://img.shields.io/discord/190307701169979393?style=plastic" alt="discord">
</a>
</p>

# logNow
is a Python package created to simplify logging for developers working on Python applications. The package provides a simple logging function that allows developers to output log messages to a file with timestamps, instead of using the standard "print" statement.

With "logNow", developers can easily create custom log messages and output them to a log file, allowing them to monitor the behavior of their applications and quickly identify any errors or issues that arise. The package provides several useful features, including support for multiple log levels, the ability to configure log formatting, and the option to output logs to the console in addition to the log file.

In addition to its core functionality, "logNow" is designed to be easy to use and configure. The package is well-documented, and the code is written in a modular and extensible manner, making it easy for developers to customize and extend its functionality to suit their needs.

Overall, "logNow" is a valuable tool for any Python developer looking to simplify their logging process and effectively monitor their applications. Whether you're working on a small hobby project or a large-scale enterprise application, "logNow" can help you keep track of what's happening in your code and quickly identify and fix any issues that arise.
## Install
<a href="https://pypi.org/project/logNow/">
    <img src="https://pypi.org/static/images/logo-small.2a411bc6.svg" alt="https://pypi.org/project/logNow/
    ">

</a>
<a href="https://pypi.org/project/logNow/">https://pypi.org/project/logNow/</a>
<p>

```cmd
pip install logNow
```
### Use
```.py
# To use logNow, you only need to import and write log("a str")

import logNow
from logNow import log

log("hello world")
log("hello red world", "R")
log("hello green world", "G")
log("hello blue world", "B")


```

## Output Example

<a href="https://pypi.org/project/logNow/">
    <img src="https://raw.githubusercontent.com/NapoII/logNow/main/Readme_ex1.png" alt="github/stars">
</a>
<a href="https://pypi.org/project/logNow/">
    <img src="https://raw.githubusercontent.com/NapoII/logNow/main/Readme_ex2.png" alt="github/stars">
</a>

## Lizenz

MIT License

Copyright (c) 2023 NapoII
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE
